==> cdktf-cdktf-provider-datadog-0.2.182.tar.gz: package/lib/data-datadog-user.d.ts <==
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface DataDatadogUserConfig extends cdktf.TerraformMetaArguments {
    /**
     * Filter all users by the given string.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/d/user.html#filter DataDatadogUser#filter}
     *
     * @stability stable
     */
    readonly filter: string;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/datadog/d/user.html datadog_user}.
 *
 * @stability stable
 */
export declare class DataDatadogUser extends cdktf.TerraformDataSource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/datadog/d/user.html datadog_user} Data Source.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: DataDatadogUserConfig);
    /**
     * @stability stable
     */
    get email(): string;
    private _filter?;
    /**
     * @stability stable
     */
    get filter(): string;
    /**
     * @stability stable
     */
    set filter(value: string);
    /**
     * @stability stable
     */
    get filterInput(): string | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}

==> cdktf-cdktf-provider-datadog-0.4.1.tar.gz: package/lib/data-datadog-user.d.ts <==
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface DataDatadogUserConfig extends cdktf.TerraformMetaArguments {
    /**
     * Filter all users by the given string.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/d/user#filter DataDatadogUser#filter}
     *
     * @stability stable
     */
    readonly filter: string;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/datadog/d/user datadog_user}.
 *
 * @stability stable
 */
export declare class DataDatadogUser extends cdktf.TerraformDataSource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/datadog/d/user datadog_user} Data Source.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: DataDatadogUserConfig);
    /**
     * @stability stable
     */
    get email(): string;
    private _filter?;
    /**
     * @stability stable
     */
    get filter(): string;
    /**
     * @stability stable
     */
    set filter(value: string);
    /**
     * @stability stable
     */
    get filterInput(): string | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
